@@ -59,3 +59,17 @@ class Characters():
 
         except Exception as e:
             return e
+
+    def get_character_by_name(self, name):
+        try:
+            url = f"{self.base_url}?name={name}"
+            headers = {
+                'Accept': 'application/json',
+                'Authorization': f"Bearer {self.api_key}"
+            }
+
+            characters = requests.request("GET", url, headers=headers).json()["docs"][0]
+            return characters
+
+        except Exception as e:
+            return e
